import "lodash-es";
import { mapGetters as u } from "vuex";
import { getRepresentativeLocaleOf as y } from "../utils/helpers.mjs";
import { openBlock as s, createElementBlock as l, createElementVNode as o, toDisplayString as c, createTextVNode as d } from "vue";
import h from "../_virtual/_plugin-vue_export-helper.mjs";
const b = {
  props: {
    modalId: {
      type: String,
      required: !0
    },
    citationStyle: {
      type: String,
      required: !0
    },
    availableCitationStyles: {
      type: Object,
      required: !0
    }
  },
  emits: ["ready"],
  data: () => ({
    currentCitationId: null,
    citation: null
    // Currently unused, but might be useful in the future
    // exportFormats: {
    //   bibtex: {
    //     name: 'BibTeX',
    //     format: 'bibtex',
    //     args: ['biblatex'],
    //     extension: 'bib',
    //   },
    //   datacite: {
    //     name: 'DataCite XML',
    //     format: 'datacite',
    //     args: ['data'],
    //     extension: 'xml',
    //     // todo
    //     disabled: true,
    //   },
    //   json: {
    //     name: 'JSON',
    //     format: 'json',
    //     args: ['data', { format: 'object' }],
    //     extension: 'json',
    //     postprocess: o => JSON.stringify(o[0], null, 2),
    //   },
    //   jsonld: {
    //     name: 'JSON-LD',
    //     format: 'json-ld',
    //     extension: 'jsonld',
    //     // todo
    //     disabled: true,
    //   },
    // },
  }),
  computed: {
    ...u("datasetDetails", [
      "getLoading",
      "getID"
    ]),
    /**
     * Provide bibliography html based on current citation and citation style
     */
    bibliographyHtml() {
      if (!this.citation)
        return "";
      let t = this.citation.format("bibliography", {
        format: "html",
        template: this.citationStyle || "apa",
        lang: "en-US"
      });
      const e = this.citationStyle === "vancouver";
      return t = t && e ? t.replace(/<div class="csl-left-margin">\d+\. <\/div>/g, "") : t, t || "";
    },
    /**
     * Provide bibliography text for clipboard content
     */
    bibliographyText() {
      return this.citation && (this.citationStyle === "vancouver" ? this.$refs.bibliography.textContent.trim() : this.citation.format("bibliography", {
        format: "text",
        template: this.citationStyle || "apa",
        lang: "en-US"
      })) || "";
    },
    isReady() {
      return this.$emit("ready"), !this.getLoading && this.citation && this.bibliographyHtml;
    }
  },
  watch: {
    // Update citation when dataset details are loaded
    // Uses watcher instead of computed property because computed is unable to
    // handle async code (i.e. citation retrieval per http request)
    getLoading: {
      /**
       * Assign citation object (CSL) based on current dataset in store to vm.citation
       */
      handler(t) {
        t || this.currentCitationId !== this.getID && (this.currentCitationId = this.getID, this.retrieveCitation(this));
      },
      immediate: !1
    }
  },
  async created() {
    const { plugins: t } = await import("@citation-js/core");
    await import("@citation-js/plugin-csl"), await import("@citation-js/plugin-doi");
    const { default: e } = await import("./plugins/dcat-state-to-csl.mjs"), { default: a } = await import("./plugins/csl-add-accessed.mjs");
    e(t), a(t);
    const { default: i } = await import("./template/deu.mjs"), n = t.config.get("@csl");
    n && n.templates.add(i.name, i.csl), this.retrieveCitation(this);
  },
  methods: {
    /**
     * Retrieves Citation Style Language (CSL) based on current dataset in store
     * Side-effect: sets vm.citation to the resulting citation object
     * @param vm Vue instance
     */
    retrieveCitation: async (t) => {
      const e = JSON.parse(JSON.stringify(t.$store.state.datasetDetails.dataset));
      if (Object.freeze(e), !e || !e.id)
        return null;
      const a = [{
        // Pass some additional data to the dataset object
        __meta: {
          // Pass the chosen dataset language for the bibliography
          lang: y(e.title, t.$route.query.locale || "en", e.languages),
          // Pass dataset URL for the bibliography
          url: `http://data.europa.eu/88u/dataset/${e.id || t.$route.params.ds_id}`,
          skipDoiNegotiation: !1
        },
        ...e
      }, {
        forceType: "@piveau/dcat-state",
        generateGraph: !1
      }];
      let i = null;
      const { Cite: n } = await import("@citation-js/core");
      try {
        return i = await n.async(...a), t.citation = i, i;
      } catch (r) {
        console.error(r);
      }
      try {
        return a[0].__meta = { ...a[0].__meta, skipDoiNegotiation: !0 }, i = await n.async(...a), t.citation = i, i;
      } catch (r) {
        console.error(r);
      }
      return i;
    },
    /**
     * Handle export of the citation
     *
     * @param {Object} format - The export format object
     * @param {String} format.args - The arguments to be passed into citation.format
     * @param {String} format.postprocess - A function to be called on the result of citation.format
     * @param {String} format.extension - The file extension
     * @param {String} format.filename - The filename
     */
    // handleCitationExport({
    //   args,
    //   postprocess = o => o,
    //   extension,
    //   filename = 'dataset',
    // }) {
    //   const exportedCitation = this.citation.format(
    //     ...args,
    //     { graph: false },
    //   );
    //   const postprocessedCitation = postprocess(exportedCitation);
    //   this.download(`${filename}.${extension}`, postprocessedCitation);
    // },
    /**
     * Download the given content as a file
     *
     * @see https://stackoverflow.com/a/45831280
     *
     * @param {String} filename - The filename
     * @param {String} content - The content to be downloaded
     */
    // download(filename, text) {
    //   const element = document.createElement('a');
    //   element.setAttribute('href', `data:text/plain;charset=utf-8,${encodeURIComponent(text)}`);
    //   element.setAttribute('download', filename);
    //   element.style.display = 'none';
    //   document.body.appendChild(element);
    //   element.click();
    //   document.body.removeChild(element);
    // },
    /**
     * Copy the bibliography to the clipboard
     */
    async handleCopyToClipboard() {
      window.getSelection().selectAllChildren(this.$refs.bibliography);
      try {
        await navigator.clipboard.writeText(this.bibliographyText);
      } catch (t) {
        console.error("Failed to copy to clipboard: ", t);
      }
    }
  }
}, g = { class: "table table-borderless table-responsive" }, m = {
  scope: "row",
  class: "text-muted font-weight-light"
}, f = { key: 0 }, C = ["innerHTML"], _ = { key: 1 }, S = { class: "mt-3 d-flex justify-content-start align-items-center" }, v = ["disabled"];
function w(t, e, a, i, n, r) {
  return s(), l("div", null, [
    o("table", g, [
      o("tbody", null, [
        o("tr", null, [
          o("th", m, c(a.availableCitationStyles[a.citationStyle]), 1),
          e[2] || (e[2] = d()),
          r.isReady ? (s(), l("td", f, [
            o("div", {
              ref: "bibliography",
              innerHTML: r.bibliographyHtml,
              "data-cy": "bibliography"
            }, null, 8, C)
          ])) : (s(), l("td", _, e[1] || (e[1] = [
            o("div", null, "...", -1)
          ])))
        ])
      ])
    ]),
    e[3] || (e[3] = d()),
    o("div", S, [
      o("button", {
        class: "btn btn-sm btn-outline-primary",
        disabled: !r.isReady,
        onClick: e[0] || (e[0] = (...p) => r.handleCopyToClipboard && r.handleCopyToClipboard(...p)),
        "data-cy": "citation-copy-to-clipboard"
      }, c(t.$t("message.cite.copyToClipboard")), 9, v)
    ])
  ]);
}
const L = /* @__PURE__ */ h(b, [["render", w]]);
export {
  L as default
};
//# sourceMappingURL=DatasetCitationTable.vue.mjs.map
