import { defineComponent as C, resolveComponent as n, openBlock as s, createElementBlock as y, mergeProps as h, normalizeClass as d, normalizeStyle as v, withKeys as l, withModifiers as m, createBlock as a, createCommentVNode as t, createTextVNode as o, createElementVNode as g, toDisplayString as k } from "vue";
import "../../config/styles/variables.css.mjs";
import "../../config/styles/typography.css.mjs";
import { PhX as b, PhCheck as K, PhMagnifyingGlass as B, PhCaretRight as V, PhCaretLeft as T, PhPlusCircle as $, PhTrash as w, PhPlusSquare as D, PhArrowCounterClockwise as M } from "@phosphor-icons/vue";
import "./ButtonV3.vue2.mjs";
import U from "../../../_virtual/_plugin-vue_export-helper.mjs";
const E = C({
  name: "ButtonV3",
  components: {
    PhX: b,
    PhCheck: K,
    PhMagnifyingGlass: B,
    PhCaretRight: V,
    PhCaretLeft: T,
    PhPlusCircle: $,
    PhTrash: w,
    PhPlusSquare: D,
    PhArrowCounterClockwise: M
  },
  props: {
    buttonText: {
      type: String,
      required: !1,
      default: null
    },
    size: {
      type: String,
      default: "medium",
      validator: (e) => ["small", "medium", "large"].includes(e)
    },
    iconStart: {
      type: String,
      default: null
    },
    iconEnd: {
      type: String,
      default: null
    },
    disabled: {
      type: Boolean,
      default: !1
    },
    variant: {
      type: String,
      default: "primary"
    },
    gapColor: {
      type: String,
      default: "white"
    }
  },
  data() {
    return {
      iconSize: "24px",
      isFocused: !1,
      isPrimaryActive: !1,
      isSecondaryActive: !1,
      isTertiaryActive: !1
    };
  },
  computed: {
    focusStyle() {
      return this.isFocused && this.variant === "tertiary" ? {
        boxShadow: "0 0 0 2px var(--Focused, #FF5733)"
      } : this.isFocused ? {
        boxShadow: `0 0 0 2px ${this.gapColor}, 0 0 0 4px var(--Focused, #0196d8)`
      } : {};
    },
    externalClass() {
      return [this.$attrs.class || ""];
    },
    dpiV3_buttonClass() {
      return [
        `dpiV3_button-base-${this.variant}`,
        `dpiV3_button-${this.size}`,
        { "dpiV3_button-disabled": this.disabled }
      ];
    },
    iconSizeClass() {
      return [
        `dpiV3_icon-${this.size}`,
        `dpiV3_icon-${this.size}-${this.variant}`
      ];
    }
  },
  methods: {
    removeFocus(e) {
      e.preventDefault(), this.addActiveState();
    },
    handleKeyPress() {
      this.disabled || (this.variant === "primary" ? this.isPrimaryActive = !0 : this.variant === "secondary" ? this.isSecondaryActive = !0 : this.variant === "tertiary" && (this.isTertiaryActive = !0));
    },
    removeActiveState() {
      this.isPrimaryActive = !1, this.isSecondaryActive = !1, this.isTertiaryActive = !1;
    },
    removeActiveStateKeyUp() {
      this.isPrimaryActive = !1, this.isSecondaryActive = !1, this.isTertiaryActive = !1, this.$emit("click");
    },
    addActiveState() {
      this.disabled || (this.variant === "primary" ? this.isPrimaryActive = !0 : this.variant === "secondary" ? this.isSecondaryActive = !0 : this.variant === "tertiary" && (this.isTertiaryActive = !0));
    }
  }
}), G = ["disabled"], q = ["disabled"], L = {
  key: 0,
  class: "dpiV3_icon"
};
function R(e, i, N, I, X, j) {
  const F = n("PhArrowCounterClockwise"), A = n("PhPlusCircle"), S = n("PhTrash"), p = n("PhMagnifyingGlass"), u = n("PhCheck"), f = n("PhCaretLeft"), P = n("PhPlusSquare"), z = n("PhCaretRight");
  return s(), y("div", h({
    class: ["dpiV3_V3-typography", e.externalClass]
  }, e.$attrs), [
    e.buttonText ? (s(), y("button", {
      key: 0,
      tabindex: "0",
      class: d([
        e.dpiV3_buttonClass,
        { activeStatePrimary: e.isPrimaryActive && e.variant === "primary" },
        { activeStateSecondary: e.isSecondaryActive && e.variant === "secondary" },
        { activeStateTertiary: e.isTertiaryActive && e.variant === "tertiary" }
      ]),
      disabled: e.disabled,
      onMousedown: i[0] || (i[0] = (...r) => e.removeFocus && e.removeFocus(...r)),
      onMouseup: i[1] || (i[1] = (...r) => e.removeActiveState && e.removeActiveState(...r)),
      style: v(e.focusStyle),
      onFocus: i[2] || (i[2] = (r) => e.isFocused = !0),
      onBlur: i[3] || (i[3] = (r) => e.isFocused = !1),
      onKeydown: [
        i[4] || (i[4] = l((...r) => e.handleKeyPress && e.handleKeyPress(...r), ["enter"])),
        i[5] || (i[5] = l(m((...r) => e.handleKeyPress && e.handleKeyPress(...r), ["prevent"]), ["space"]))
      ],
      onKeyup: [
        i[6] || (i[6] = l((...r) => e.removeActiveStateKeyUp && e.removeActiveStateKeyUp(...r), ["enter"])),
        i[7] || (i[7] = l((...r) => e.removeActiveStateKeyUp && e.removeActiveStateKeyUp(...r), ["space"]))
      ]
    }, [
      e.iconStart ? (s(), y("span", {
        key: 0,
        class: d(["dpiV3_icon", e.iconSizeClass])
      }, [
        e.iconStart === "reset" ? (s(), a(F, {
          key: 0,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[16] || (i[16] = o()),
        e.iconStart === "plus" ? (s(), a(A, {
          key: 1,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[17] || (i[17] = o()),
        e.iconStart === "trash" ? (s(), a(S, {
          key: 2,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[18] || (i[18] = o()),
        e.iconStart === "MagnifyingGlass" ? (s(), a(p, {
          key: 3,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[19] || (i[19] = o()),
        e.iconStart === "Check" ? (s(), a(u, {
          key: 4,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[20] || (i[20] = o()),
        e.iconStart === "CaretLeft" ? (s(), a(f, {
          key: 5,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[21] || (i[21] = o()),
        e.iconStart === "PlusSquare" ? (s(), a(P, {
          key: 6,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0)
      ], 2)) : t("", !0),
      i[24] || (i[24] = o()),
      g("span", null, k(e.buttonText), 1),
      i[25] || (i[25] = o()),
      e.iconEnd ? (s(), y("span", {
        key: 1,
        class: d(["dpiV3_icon", e.iconSizeClass])
      }, [
        e.iconEnd === "MagnifyingGlass" ? (s(), a(p, {
          key: 0,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[22] || (i[22] = o()),
        e.iconEnd === "Check" ? (s(), a(u, {
          key: 1,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[23] || (i[23] = o()),
        e.iconEnd === "CaretRight" ? (s(), a(z, {
          key: 2,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0)
      ], 2)) : t("", !0)
    ], 46, G)) : t("", !0),
    i[27] || (i[27] = o()),
    e.buttonText ? t("", !0) : (s(), y("div", {
      key: 1,
      tabindex: "0",
      class: d([
        "dpiV3_button-icon-only",
        e.iconSizeClass,
        { "dpiV3_button-icon-only-large": e.size === "large" },
        { activeStatePrimary: e.isPrimaryActive && e.variant === "primary" },
        { activeStateSecondary: e.isSecondaryActive && e.variant === "secondary" },
        { activeStateTertiary: e.isTertiaryActive && e.variant === "tertiary" }
      ]),
      disabled: e.disabled,
      onMousedown: i[8] || (i[8] = (...r) => e.removeFocus && e.removeFocus(...r)),
      onMouseup: i[9] || (i[9] = (...r) => e.removeActiveState && e.removeActiveState(...r)),
      style: v(e.focusStyle),
      onFocus: i[10] || (i[10] = (r) => e.isFocused = !0),
      onBlur: i[11] || (i[11] = (r) => e.isFocused = !1),
      onKeydown: [
        i[12] || (i[12] = l((...r) => e.handleKeyPress && e.handleKeyPress(...r), ["enter"])),
        i[13] || (i[13] = l(m((...r) => e.handleKeyPress && e.handleKeyPress(...r), ["prevent"]), ["space"]))
      ],
      onKeyup: [
        i[14] || (i[14] = l((...r) => e.removeActiveStateKeyUp && e.removeActiveStateKeyUp(...r), ["enter"])),
        i[15] || (i[15] = l((...r) => e.removeActiveStateKeyUp && e.removeActiveStateKeyUp(...r), ["space"]))
      ]
    }, [
      e.buttonText ? t("", !0) : (s(), y("span", L, [
        e.iconStart === "MagnifyingGlass" ? (s(), a(p, {
          key: 0,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0),
        i[26] || (i[26] = o()),
        e.iconStart === "Check" ? (s(), a(u, {
          key: 1,
          size: e.size === "small" ? "16px" : "24px",
          color: e.variant === "primary" ? "#FFFFFF" : e.variant === "secondary" ? "#0B1A25" : "#0172AD"
        }, null, 8, ["size", "color"])) : t("", !0)
      ]))
    ], 46, q))
  ], 16);
}
const Z = /* @__PURE__ */ U(E, [["render", R], ["__scopeId", "data-v-83417092"]]);
export {
  Z as default
};
//# sourceMappingURL=ButtonV3.vue.mjs.map
