declare const formModule: {
    state: {
        schema: {
            datasets: {};
            distributions: {};
            catalogues: {};
        };
        usersCatalogs: {};
    };
    getters: {
        getSchema: (state: any) => (property: any) => any;
    };
    actions: {
        /**
         * Commits page properties and related DCATAP property definitions for current view for later building of schema
         * @param {Object} param0
         * @param {Object} param1 Object containing property (datasets/catalogues), page (step1/step2/step3) and subpage (distribution1/distribution2/distribution3) of current view
         */
        createSchema({ commit, state, rootGetters }: {
            commit: any;
            state: any;
            rootGetters: any;
        }, { property, page }: {
            property: any;
            page: any;
        }): void;
        /**
         * Calls mutation function for translating translatable properties of schema
         * @param {*} param0
         */
        translateSchema({ commit }: {
            commit: any;
        }, { property, page }: {
            property: any;
            page: any;
        }): void;
        /**
         * Commits current property and users catalogs to mutation function
         * @param {*} param0
         * @param {*} param1 Object containing curren tproperty (datasets/catalogues) and all catalog options the user has permissions for
         */
        addCatalogOptions({ commit }: {
            commit: any;
        }, { property, catalogs }: {
            property: any;
            catalogs: any;
        }): void;
    };
    mutations: {
        /**
         * Builds schema based on given pageProperties and their definitions provided by propertyDefinition
         * @param {Object} state
         * @param {Object} param1 Object containing the properties which should be displayed within the view
         * (pageProperties) and the form definitions of the properties defined by DCATAP (propertyDefinition)
         */
        extractSchema(state: any, { pageProperties, propertyDefinitions, property, page }: {
            pageProperties: any;
            propertyDefinitions: any;
            property: any;
            page: any;
        }): void;
        /**
         * All translatable properties within the existing schema will be translated and added to the schema
         * @param {*} state
         * @param {String} property String defining current property (datasets/ distribution/ catalogues)
         */
        translateSchemaProperties(state: any, { property, page }: {
            property: any;
            page: any;
        }): void;
        /**
         * Saves all catalogs the current user has permissions for as options within the schema
         * @param {*} state
         * @param {*} param1 Object containing current property and the users catalog options
         */
        saveCatalogOptions(state: any, { property, catalogs }: {
            property: any;
            catalogs: any;
        }): void;
    };
};
export default formModule;
