import { isNil as g, has as h } from "lodash-es";
import { getTranslationFor as p, truncate as V } from "../../utils/helpers.mjs";
import { mapGetters as x } from "vuex";
import C from "../../widgets/AppLink.vue.mjs";
import { resolveComponent as y, openBlock as l, createElementBlock as o, createVNode as f, createTextVNode as n, createElementVNode as e, Fragment as v, renderList as b, toDisplayString as r, createCommentVNode as D, withCtx as w } from "vue";
import "./DatasetDetailsFeatureHeader.vue2.mjs";
import F from "../../_virtual/_plugin-vue_export-helper.mjs";
import "./DatasetDetailsVisualisations.vue2.mjs";
const L = {
  name: "DatasetDetailsVisualisations",
  components: {
    // DatasetDetailsFeatureHeader,
    AppLink: C
  },
  props: {
    trackGoto: Function
  },
  data() {
    return {
      expandedVisualisationDescriptions: [],
      expandedVisualisations: [],
      visualisations: {
        isVisible: this.$env.content.datasetDetails.visualisations.isVisible,
        displayAll: this.$env.content.datasetDetails.visualisations.displayAll,
        displayCount: this.$env.content.datasetDetails.visualisations.displayCount,
        incrementSteps: this.$env.content.datasetDetails.visualisations.incrementSteps,
        descriptionMaxLines: this.$env.content.datasetDetails.visualisations.descriptionMaxLines,
        descriptionMaxChars: this.$env.content.datasetDetails.visualisations.descriptionMaxChars
      }
    };
  },
  computed: {
    ...x("datasetDetails", [
      "getLanguages",
      "getVisualisations"
    ]),
    isVisualisationsAllDisplayed() {
      return this.visualisations.displayCount === this.getVisualisations.length;
    },
    remainingVisualisations() {
      return this.getVisualisations.length - this.visualisations.displayCount;
    },
    displayedVisualisations() {
      const s = [...this.getVisualisations].sort((t, u) => p(t.title, this.$route.query.locale, this.getLanguages) < p(u.title, this.$route.query.locale, this.getLanguages) ? -1 : p(t.title, this.$route.query.locale, this.getLanguages) > p(u.title, this.$route.query.locale, this.getLanguages) ? 1 : 0);
      return this.visualisations.displayAll ? Object.freeze(s) : Object.freeze(s.slice(0, this.visualisations.displayCount));
    }
  },
  methods: {
    truncate: V,
    toggleVisualisation() {
      this.visualisations.isVisible = !this.visualisations.isVisible;
    },
    toggleVisualisationDescription(s) {
      const t = this.expandedVisualisationDescriptions.indexOf(s);
      t > -1 ? this.expandedVisualisationDescriptions.splice(t, 1) : this.expandedVisualisationDescriptions.push(s);
    },
    visualisationIsExpanded(s) {
      return this.expandedVisualisations.includes(s);
    },
    visualisationDescriptionIsExpanded(s) {
      return this.expandedVisualisationDescriptions.includes(s);
    },
    visualisationDescriptionIsExpandable(s) {
      return g(s) ? !1 : s.length > this.visualisations.descriptionMaxChars;
    },
    // Increases the current number of distributions displayed
    // and clamps the result so that it never exceeds the number of all distributions.
    increaseNumDisplayedVisualisations(s) {
      const t = this.clamp(this.visualisations.displayCount + s, 0, this.getVisualisations.length);
      this.visualisations.displayCount = t;
    },
    nonOverflowingIncrementsForVisualisations(s) {
      return this.visualisations.displayCount + s <= this.getVisualisations.length;
    },
    getVisualisationFormat(s) {
      return h(s, "format.label") && !g(s.format.label) ? s.format.label : "UNKNOWN";
    },
    visualisationFormatTruncated(s) {
      return this.getVisualisationFormat(s).length > 4;
    },
    getVisualisationTitle(s) {
      return s.title ? p(s.title, this.$route.query.locale, this.getLanguages) : V(s.resource, 50);
    },
    getVisualisationDescription(s) {
      return h(s, "description") && !g(s.description) ? p(s.description, this.$route.query.locale, this.getLanguages) : this.$t("message.catalogsAndDatasets.noDescriptionAvailable");
    },
    clamp(s, t, u) {
      return Math.min(Math.max(s, t), u);
    }
  }
}, A = { class: "dsd-feature" }, M = {
  key: 0,
  class: "list list-unstyled col-12"
}, N = {
  key: 0,
  class: "distributions__item--preview"
}, T = { class: "distributions__actions pb-md-3" }, I = ["onClick"], E = { class: "row" }, S = { class: "d-inline-block col-2 col-md-1 pl-1 p-md-3 px-md-4 m-md-0 m-auto" }, q = ["type", "data-toggle", "data-placement", "title"], O = { class: "col-10 col-md-11" }, G = { class: "row" }, j = { class: "d-inline-block col-12" }, z = ["title"], B = { class: "d-inline-block col-12 col-md-9 col-lg-7" }, U = { class: "mt-2 d-block" }, K = { key: 0 }, W = { class: "text-muted" }, X = ["onClick"], $ = { key: 1 }, H = { class: "text-muted" }, J = { key: 2 }, P = { class: "text-muted" }, Q = ["onClick"], R = { class: "col-12 col-md-3 col-lg-5 mt-2 text-md-right text-left" }, Y = { class: "download dropdown d-inline-block" };
function Z(s, t, u, ss, d, i) {
  const _ = y("dataset-details-feature-header"), k = y("app-link");
  return l(), o("div", A, [
    f(_, {
      title: `${s.$t("message.metadata.visualisations")} (${s.getVisualisations ? s.getVisualisations.length.toLocaleString("fi") : 0})`,
      arrowDown: !d.visualisations.isVisible,
      onClick: i.toggleVisualisation
    }, null, 8, ["title", "arrowDown", "onClick"]),
    t[12] || (t[12] = n()),
    d.visualisations.isVisible ? (l(), o("ul", M, [
      t[10] || (t[10] = e("hr", null, null, -1)),
      t[11] || (t[11] = n()),
      (l(), o("div", {
        class: "distributions",
        key: `${d.expandedVisualisations.length}--${d.expandedVisualisationDescriptions.length}`
      }, [
        (l(!0), o(v, null, b(i.displayedVisualisations, (a, m) => (l(), o("div", {
          key: m,
          class: "distributions__item"
        }, [
          !d.visualisations.displayAll && !i.isVisualisationsAllDisplayed && m === d.visualisations.displayCount - 1 ? (l(), o("div", N, [
            e("div", T, [
              (l(!0), o(v, null, b(d.visualisations.incrementSteps.filter(i.nonOverflowingIncrementsForVisualisations), (c) => (l(), o("button", {
                key: c,
                class: "btn btn-sm btn-secondary mr-1",
                onClick: (ts) => i.increaseNumDisplayedVisualisations(c)
              }, [
                t[1] || (t[1] = e("i", { class: "fas fa-chevron-down" }, null, -1)),
                n(" " + r(s.$t("message.metadata.showXMore", { increment: c })), 1)
              ], 8, I))), 128)),
              t[3] || (t[3] = n()),
              e("button", {
                class: "btn btn-sm btn-primary",
                onClick: t[0] || (t[0] = (c) => d.visualisations.displayCount = s.getVisualisations.length)
              }, [
                t[2] || (t[2] = e("i", { class: "fas fa-eye" }, null, -1)),
                n(" " + r(s.$t("message.metadata.showAll")) + " " + r(s.getVisualisations.length.toLocaleString("fi")), 1)
              ])
            ])
          ])) : D("", !0),
          t[7] || (t[7] = n()),
          e("li", E, [
            e("span", S, [
              e("div", {
                class: "circle float-md-right text-center text-white",
                type: i.getVisualisationFormat(a),
                "data-toggle": i.visualisationFormatTruncated(a) ? "tooltip" : !1,
                "data-placement": i.visualisationFormatTruncated(a) ? "top" : !1,
                title: i.visualisationFormatTruncated(a) ? i.getVisualisationFormat(a) : !1
              }, [
                e("span", null, r(i.truncate(i.getVisualisationFormat(a), 4, !0)), 1)
              ], 8, q)
            ]),
            t[6] || (t[6] = n()),
            e("span", O, [
              e("span", G, [
                e("span", j, [
                  e("h3", {
                    class: "m-0 text-break",
                    title: i.getVisualisationTitle(a)
                  }, r(i.getVisualisationTitle(a)), 9, z)
                ]),
                t[4] || (t[4] = n()),
                e("span", B, [
                  e("span", U, [
                    i.visualisationDescriptionIsExpanded(`visualisation-description-toggle-${m}`) ? (l(), o("small", K, [
                      e("p", W, [
                        n(r(i.getVisualisationDescription(a)) + " ", 1),
                        e("span", {
                          class: "text-primary details-link pl-2",
                          onClick: (c) => i.toggleVisualisationDescription(`visualisation-description-toggle-${m}`)
                        }, r(s.$t("message.metadata.readLess")), 9, X)
                      ])
                    ])) : i.visualisationDescriptionIsExpandable(i.getVisualisationDescription(a)) ? (l(), o("small", J, [
                      e("p", P, [
                        n(r(i.truncate(i.getVisualisationDescription(a), d.visualisations.descriptionMaxChars)) + " ", 1),
                        e("span", {
                          class: "text-primary details-link pl-2",
                          onClick: (c) => i.toggleVisualisationDescription(`visualisation-description-toggle-${m}`)
                        }, r(s.$t("message.metadata.readMore")), 9, Q)
                      ])
                    ])) : (l(), o("small", $, [
                      e("p", H, r(i.getVisualisationDescription(a)), 1)
                    ]))
                  ])
                ]),
                t[5] || (t[5] = n()),
                e("span", R, [
                  e("span", Y, [
                    f(k, {
                      class: "btn btn-sm btn-primary p-0 pl-2 pr-2 w-100 rounded-lg btn-color",
                      to: a.accessUrl[0],
                      target: "_blank",
                      rel: "dcat:distribution noopener",
                      "matomo-track-download": "",
                      onAfterClick: u.trackGoto
                    }, {
                      default: w(() => [
                        n(r(s.$t("message.datasetDetails.access")), 1)
                      ]),
                      _: 2
                    }, 1032, ["to", "onAfterClick"])
                  ])
                ])
              ])
            ])
          ]),
          t[8] || (t[8] = n()),
          t[9] || (t[9] = e("hr", { class: "mt-1" }, null, -1))
        ]))), 128))
      ]))
    ])) : D("", !0)
  ]);
}
const us = /* @__PURE__ */ F(L, [["render", Z], ["__scopeId", "data-v-fb260c61"]]);
export {
  us as default
};
//# sourceMappingURL=DatasetDetailsVisualisations.vue.mjs.map
